@@ -117,7 +117,8 @@ case "$switch" in
      #
      if  [ "$prepare_ocsroot" = "yes" ]; then
         echo "Preparing clonezilla image home dir..."
-	prep-ocsroot
+	prep-ocsroot --skip-ocsroot-mountpoint-chk  # will check later to avoid the exit is only for prep-ocsroot program, not for this $0.
+        check_if_ocsroot_a_mountpoint
      fi
 
      #
